jQuery(document).ready(function($) {
    $('#ytd-submit').on('click', function() {
        const url = $('#ytd-url').val().trim();
        
        if (!url) {
            $('.ytd-error').text('Please enter a YouTube URL').show();
            return;
        }
        
        // Show loading
        $('.ytd-loading').show();
        $('.ytd-thumbnails').empty();
        $('.ytd-error').hide();
        
        // Send AJAX request
        $.ajax({
            url: ytd_ajax.ajax_url,
            type: 'POST',
            data: {
                action: 'ytd_get_thumbnails',
                url: url
            },
            success: function(response) {
                $('.ytd-loading').hide();
                
                if (response.success) {
                    const data = response.data;
                    const videoId = data.video_id;
                    const thumbnails = data.thumbnails;
                    
                    // Display thumbnails
                    for (const [quality, url] of Object.entries(thumbnails)) {
                        const qualityLabel = quality.charAt(0).toUpperCase() + quality.slice(1);
                        
                        const thumbnailItem = `
                            <div class="ytd-thumbnail-item">
                                <img src="${url}" alt="YouTube thumbnail ${qualityLabel}">
                                <div class="ytd-thumbnail-info">
                                    <h3>${qualityLabel} Quality</h3>
                                    <a href="${url}" download="youtube-thumbnail-${videoId}-${quality}.jpg" target="_blank">Download</a>
                                </div>
                            </div>
                        `;
                        
                        $('.ytd-thumbnails').append(thumbnailItem);
                    }
                } else {
                    $('.ytd-error').text(response.data.message).show();
                }
            },
            error: function() {
                $('.ytd-loading').hide();
                $('.ytd-error').text('An error occurred. Please try again.').show();
            }
        });
    });
});