<?php
/**
 * Plugin Name: YouTube Thumbnail Downloader
 * Plugin URI: https://seomarketguru.com/
 * Description: A simple tool to download YouTube video thumbnails
 * Version: 1.1
 * Author: Muhammad Anas Abbas
 * Author URI: https://seomarketguru.com/
 * Text Domain: youtube-thumbnail-downloader
 */

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}

// Enqueue scripts and styles
function ytd_enqueue_scripts() {
    wp_enqueue_style('ytd-styles', plugin_dir_url(__FILE__) . 'assets/css/style.css', array(), '1.0.0');
    wp_enqueue_script('ytd-script', plugin_dir_url(__FILE__) . 'assets/js/script.js', array('jquery'), '1.0.0', true);
    
    // Pass ajax url to script
    wp_localize_script('ytd-script', 'ytd_ajax', array(
        'ajax_url' => admin_url('admin-ajax.php')
    ));
}
add_action('wp_enqueue_scripts', 'ytd_enqueue_scripts');

// Create shortcode for the thumbnail downloader
function ytd_thumbnail_downloader_shortcode() {
    ob_start();
    ?>
    <div class="ytd-container">
        <h2><?php _e('YouTube Thumbnail Downloader', 'youtube-thumbnail-downloader'); ?></h2>
        <div class="ytd-form">
            <input type="text" id="ytd-url" placeholder="<?php _e('Enter YouTube Video URL', 'youtube-thumbnail-downloader'); ?>">
            <button id="ytd-submit"><?php _e('Get Thumbnails', 'youtube-thumbnail-downloader'); ?></button>
        </div>
        <div class="ytd-results">
            <div class="ytd-loading" style="display: none;">
                <p><?php _e('Loading...', 'youtube-thumbnail-downloader'); ?></p>
            </div>
            <div class="ytd-thumbnails"></div>
            <div class="ytd-error" style="display: none;"></div>
        </div>
    </div>
    <?php
    return ob_get_clean();
}
add_shortcode('youtube_thumbnail_downloader', 'ytd_thumbnail_downloader_shortcode');

// AJAX handler for getting thumbnails
function ytd_get_thumbnails() {
    $url = isset($_POST['url']) ? sanitize_text_field($_POST['url']) : '';
    
    if (empty($url)) {
        wp_send_json_error(array('message' => __('Please enter a valid YouTube URL', 'youtube-thumbnail-downloader')));
    }
    
    // Extract video ID from URL
    $video_id = ytd_extract_video_id($url);
    
    if (!$video_id) {
        wp_send_json_error(array('message' => __('Invalid YouTube URL', 'youtube-thumbnail-downloader')));
    }
    
    // Get thumbnails
    $thumbnails = array(
        'default' => "https://img.youtube.com/vi/{$video_id}/default.jpg",
        'medium' => "https://img.youtube.com/vi/{$video_id}/mqdefault.jpg",
        'high' => "https://img.youtube.com/vi/{$video_id}/hqdefault.jpg",
        'standard' => "https://img.youtube.com/vi/{$video_id}/sddefault.jpg",
        'maxres' => "https://img.youtube.com/vi/{$video_id}/maxresdefault.jpg"
    );
    
    wp_send_json_success(array(
        'video_id' => $video_id,
        'thumbnails' => $thumbnails
    ));
}
add_action('wp_ajax_ytd_get_thumbnails', 'ytd_get_thumbnails');
add_action('wp_ajax_nopriv_ytd_get_thumbnails', 'ytd_get_thumbnails');

// Helper function to extract YouTube video ID
function ytd_extract_video_id($url) {
    $pattern = '/(?:youtube\.com\/(?:[^\/\n\s]+\/\S+\/|(?:v|e(?:mbed)?)\/|\S*?[?&]v=)|youtu\.be\/)([a-zA-Z0-9_-]{11})/';
    preg_match($pattern, $url, $matches);
    
    return isset($matches[1]) ? $matches[1] : false;
}